pub async fn get_user_field(user_id: i32, field: &str) -> HttpResponseExpand description
Get a user field from the database.
This function retrieves a specific field from the users table for a given user ID.
Arguments
user_id: The ID of the user to retrieve the field for.field: The name of the field to retrieve.
Returns
An HttpResponse containing the value of the field or an error message if the field is not found.