init_db

Function init_db 

pub async fn init_db() -> Result<Pool<Sqlite>, Error>
Initialize the database connection.

This function creates a connection pool to the SQLite database specified in the DATABASE_URL environment variable. If the variable is not set, it defaults to sqlite:./users.db.db.

Returns

A Result containing the connection pool or an error if the connection fails.