pub struct LoginResponse {
pub token: String,
}Expand description
Response struct for user registration
This struct is used to serialize the response data for user registration. It contains a field for the users token, which is used for authentication.
Fields
token: StringTrait Implementations